# -*- coding: utf-8 -*-


def get_stop_loss_price(price, stop, relative_stop=False):
    """Returns the stop loss price. The actual stop loss price is
    calculated from the piven stop. The stop can be set in abosult
    (default) or in relative values to the price.

    Please note that the stop must be positive for BUY orders and
    negative for SELL orders.

    :price: Current price you want to buy/sell.
    :stop: Stop price.
    :relative_stop: Flag that the stop is interpreted as relative value
    and not as absolut value.
    :returns: Price where to set the stop loss
    """
    if relative_stop:
        sl_price = price - stop
    else:
        sl_price = stop
    return sl_price


def get_risk_per_unit(price, sl_price):
    """Returns the risk per unit as difference of the current price
    minus the stop loss price.

    Example:
    If the current price of the unit is 10$ and your stop loss price is
    set to 9$ the risk per unit is 1$

    :price: Current price you want to buy/sell.
    :sl_price: Stop loss pricel.
    :returns: Amount the buy/sell price can raise/fall per unit.
    """
    return abs(price - sl_price)


def get_position_size(insert, risk_per_unit):
    """Returns number of items you can buy with the given insert at the
    given risk.

    Example:
    If you have an max insert to 10$ which you can afford to loose and
    the risk per unit (calculated from the current unit price and its
    stop loss price) is 1$ you can buy 10 units.

    :insert: Max amount of money you set at risk to loose.
    :risk_per_unit: Amount the buy/sell price can raise/fall per unit.
    :returns: Number of units you can buy.
    """
    return insert / risk_per_unit


def get_position_value(price, size):
    """Returns the value of your position. This is the amountof money
    you must set into BUY order or which you get when doing a SELL order.

    :price: Current price you want to buy/sell.
    :size: How many do you want to buy/sell
    :returns: Value of your position.
    """
    return price * size



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_tradecalc
----------------------------------

Tests for `tradecalc` module.
"""

from click.testing import CliRunner
from tradecalc import cli


def test_interface():
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0


def test_help():
    runner = CliRunner()
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output


def test_buy():
    runner = CliRunner()
    help_result = runner.invoke(cli.main, ['buy', '100', '10', '10', '--relative-stop'])
    assert help_result.exit_code == 0
    assert 'Stop Loss at price at 90.0$' in help_result.output


def test_sell():
    runner = CliRunner()
    help_result = runner.invoke(cli.main, ['sell', '100', '10', '10', '--relative-stop'])
    assert help_result.exit_code == 0
    assert 'Stop Loss at price at 110.0$' in help_result.output



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_tradecalc
----------------------------------

Tests for `tradecalc` module.
"""


def test_get_stop_loss_price():
    from tradecalc.tradecalc import get_stop_loss_price
    # BUY percentage
    sl = get_stop_loss_price(150, 135)
    assert sl == 135
    # SELL percentage
    sl = get_stop_loss_price(150, 165)
    assert sl == 165
    # BUY absolut
    sl = get_stop_loss_price(150, 5, True)
    assert sl == 145
    # SELL absolut
    sl = get_stop_loss_price(150, -5, True)
    assert sl == 155


def test_get_risk_per_unit():
    from tradecalc.tradecalc import get_risk_per_unit
    rpu = get_risk_per_unit(100, 90)
    assert rpu == 10


def test_get_position_size():
    from tradecalc.tradecalc import get_position_size
    ps = get_position_size(100, 5)
    assert ps == 20


def test_get_position_value():
    from tradecalc.tradecalc import get_position_value
    ps = get_position_value(100, 20)
    assert ps == 2000



# -*- coding: utf-8 -*-
import click
from tradecalc.tradecalc import (
    get_stop_loss_price,
    get_risk_per_unit,
    get_position_size,
    get_position_value
)


@click.group()
def main(args=None):
    """Console script for tradingtool"""


@click.command()
@click.argument("price", type=float)
@click.argument("stop", type=float)
@click.argument("insert", type=float)
@click.option("--relative-stop", is_flag=True)
def buy(price, stop, insert, relative_stop):
    """Calc max position for a buy order."""
    sl_price = get_stop_loss_price(price, stop, relative_stop)

    # Max units we can buy
    position_size = get_position_size(insert, get_risk_per_unit(price, sl_price))
    position_value = get_position_value(price, position_size)

    # If you set the SL at `sl_price` you can by for `position_value`
    # at `price` with a maximum loss of `insert`.
    click.echo("Stop Loss at price at {}$".format(sl_price))
    click.echo("Size of position {} units ({}$)".format(position_size, position_value))


@click.command()
@click.argument("price", type=float)
@click.argument("stop", type=float)
@click.argument("insert", type=float)
@click.option("--relative-stop", is_flag=True)
def sell(price, stop, insert, relative_stop):
    """Calc max position for a sell order."""
    sl_price = get_stop_loss_price(price, stop * -1, relative_stop)

    # Max units we can buy
    position_size = get_position_size(insert, get_risk_per_unit(price, sl_price))
    position_value = get_position_value(price, position_size)

    # If you set the SL at `sl_price` you can by for `position_value`
    # at `price` with a maximum loss of `insert`.
    click.echo("Stop Loss at price at {}$".format(sl_price))
    click.echo("Size of position {} units ({}$)".format(position_size, position_value))


main.add_command(buy)
main.add_command(sell)
